#Camera is saved to the file "savedCamera" in this plugin's folder
#Save file is a single line with semi-colon separated values.
#All values are saved as strings.
#Lengths includes unit.
#Remember adding the unit when writing scripts in other programs that outputs a camera.
#This is the order of the values:
#	EyeX
#	EyeY
#	EyeZ
#	TargetX
#	TargetY
#	TargetZ
#	UpX
#	UpY
#	UpZ
#	Aspect ratio
#	Perspective
#	Fov OR Height

module Ene_camMemory

menu = UI.menu("Camera")
menu.add_item("将当前镜头放入缓存内") { self.saveCam }
menu.add_item("调取缓存内镜头至当前") { self.recoverCam }
  path = Sketchup.find_support_file("Plugins/ene_camMemory")
  cammemory_tb = UI::Toolbar.new("缓存相机")
  #标注
  cmd = UI::Command.new(("将当前镜头放入缓存内")) { self.saveCam }
  cmd.small_icon = File.join(path,"icons/hcxj1_24.png")
  cmd.large_icon = File.join(path,"icons/hcxj1_36.png")
  cmd.tooltip = "将当前镜头放入缓存内"
  cmd.status_bar_text = "可以将相机的位置保存在缓存中，以便在其它模型中调取该镜头"
  cammemory_tb.add_item(cmd) 
  cmd = UI::Command.new(("调取缓存内镜头至当前")) { self.recoverCam }
  cmd.small_icon = File.join(path,"icons/hcxj2_24.png")
  cmd.large_icon = File.join(path,"icons/hcxj2_36.png")
  cmd.tooltip = "调取缓存内镜头至当前"
  cmd.status_bar_text = "在缓存内有相机信息的情况下，点击该按钮调取该镜头信息"
  cammemory_tb.add_item(cmd) 
  cammemory_tb.show

def self.saveCam
	#Save all parameters to file
	cam = Sketchup.active_model.active_view.camera
	parameters = []
	parameters << cam.eye.x.to_s
	parameters << cam.eye.y.to_s
	parameters << cam.eye.z.to_s
	parameters << cam.target.x.to_s
	parameters << cam.target.y.to_s
	parameters << cam.target.z.to_s
	parameters << cam.up.x.to_s
	parameters << cam.up.y.to_s
	parameters << cam.up.z.to_s
	parameters << cam.aspect_ratio.to_s
	parameters << cam.perspective?
	parameters << cam.fov.to_s if cam.perspective?
	parameters << cam.height.to_s unless cam.perspective?
	parameterString = parameters.join(";")
	path = File.dirname(__FILE__) + "/savedCamera"
	file = File.new(path, "w")
	file.print parameterString
	file.close
end#def

def self.recoverCam
	#Retrieve all camera parameters from file
	path = File.dirname(__FILE__) + "/savedCamera"
	unless File.exists? path then
		UI.messagebox("没有保存的镜头")
		return
	end#unless
	file = File.open(path)
	parameterString = file.readline.to_s
	file.close
	parameters = parameterString.split(";")
	cam = Sketchup.active_model.active_view.camera
	eye = Geom::Point3d.new(parameters[0].to_l,parameters[1].to_l,parameters[2].to_l)
	target = Geom::Point3d.new(parameters[3].to_l,parameters[4].to_l,parameters[5].to_l)
	up = Geom::Vector3d.new(parameters[6].to_f,parameters[7].to_f,parameters[8].to_f)
	cam.set eye, target, up
	cam.aspect_ratio = parameters[9].to_f
	cam.perspective = parameters[10] == "true"
	cam.fov = parameters[11].to_f if parameters[10] == "true"
	cam.height = parameters[11].to_f unless parameters[10] == "true"
end#def

end#module